@@ -9,7 +9,7 @@ func <- function(v,fu,m,nfmax,da,ga,tr,nql)
 		}
 	}
 
-	dchole <- .Fortran("dchole",fu=as.double(fu),as.integer(m),as.integer(nql),idpos=as.integer(0),PACKAGE="marquardt")
+	dchole <- .Fortran("dchole",fu=as.double(fu),as.integer(m),as.integer(nql),idpos=as.integer(0),PACKAGE="marqLevAlg")
 	idpos <- dchole$idpos
 	fu <-dchole$fu
 	result <- list(idpos=idpos,fu=fu)
